# mypy-boto3-codepipeline

[![PyPI - mypy-boto3-codepipeline](https://img.shields.io/pypi/v/mypy-boto3-codepipeline.svg?color=blue)](https://pypi.org/project/mypy-boto3-codepipeline)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-codepipeline.svg?color=blue)](https://pypi.org/project/mypy-boto3-codepipeline)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.CodePipeline 1.16.51](https://boto3.amazonaws.com/v1/documentation/api/1.16.51/reference/services/codepipeline.html#CodePipeline) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-codepipeline](#mypy-boto3-codepipeline)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `CodePipeline` service.

```bash
python -m pip install boto3-stubs[codepipeline]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[codepipeline]` in your environment: `python -m pip install 'boto3-stubs[codepipeline]'`

Both type checking and auto-complete should work for `CodePipeline` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[codepipeline]` in your environment: `python -m pip install 'boto3-stubs[codepipeline]'`

Both type checking and auto-complete should work for `CodePipeline` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[codepipeline]` in your environment: `python -m pip install 'boto3-stubs[codepipeline]'`
- Run `mypy` as usual

Type checking should work for `CodePipeline` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[codepipeline]` in your environment: `python -m pip install 'boto3-stubs[codepipeline]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CodePipeline` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`CodePipelineClient` provides annotations for `boto3.client("codepipeline")`.

```python
import boto3

from mypy_boto3_codepipeline import CodePipelineClient

client: CodePipelineClient = boto3.client("codepipeline")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CodePipelineClient = session.client("codepipeline")
```

### Paginators annotations

`mypy_boto3_codepipeline.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_codepipeline import CodePipelineClient
from mypy_boto3_codepipeline.paginator import (
    ListActionExecutionsPaginator,
    ListActionTypesPaginator,
    ListPipelineExecutionsPaginator,
    ListPipelinesPaginator,
    ListTagsForResourcePaginator,
    ListWebhooksPaginator,
)

client: CodePipelineClient = boto3.client("codepipeline")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_action_executions_paginator: ListActionExecutionsPaginator = client.get_paginator("list_action_executions")
list_action_types_paginator: ListActionTypesPaginator = client.get_paginator("list_action_types")
list_pipeline_executions_paginator: ListPipelineExecutionsPaginator = client.get_paginator("list_pipeline_executions")
list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
list_webhooks_paginator: ListWebhooksPaginator = client.get_paginator("list_webhooks")
```







### Typed dictionations

`mypy_boto3_codepipeline.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_codepipeline.type_defs import (
    AcknowledgeJobOutputTypeDef,
    AcknowledgeThirdPartyJobOutputTypeDef,
    ActionConfigurationPropertyTypeDef,
    ActionConfigurationTypeDef,
    ActionContextTypeDef,
    ActionDeclarationTypeDef,
    ActionExecutionDetailTypeDef,
    ActionExecutionFilterTypeDef,
    ActionExecutionInputTypeDef,
    ActionExecutionOutputTypeDef,
    ActionExecutionResultTypeDef,
    ActionExecutionTypeDef,
    ActionRevisionTypeDef,
    ActionStateTypeDef,
    ActionTypeIdTypeDef,
    ActionTypeSettingsTypeDef,
    ActionTypeTypeDef,
    ApprovalResultTypeDef,
    ArtifactDetailsTypeDef,
    ArtifactDetailTypeDef,
    ArtifactLocationTypeDef,
    ArtifactRevisionTypeDef,
    ArtifactStoreTypeDef,
    ArtifactTypeDef,
    AWSSessionCredentialsTypeDef,
    BlockerDeclarationTypeDef,
    CreateCustomActionTypeOutputTypeDef,
    CreatePipelineOutputTypeDef,
    CurrentRevisionTypeDef,
    EncryptionKeyTypeDef,
    ErrorDetailsTypeDef,
    ExecutionDetailsTypeDef,
    ExecutionTriggerTypeDef,
    FailureDetailsTypeDef,
    GetJobDetailsOutputTypeDef,
    GetPipelineExecutionOutputTypeDef,
    GetPipelineOutputTypeDef,
    GetPipelineStateOutputTypeDef,
    GetThirdPartyJobDetailsOutputTypeDef,
    InputArtifactTypeDef,
    JobDataTypeDef,
    JobDetailsTypeDef,
    JobTypeDef,
    ListActionExecutionsOutputTypeDef,
    ListActionTypesOutputTypeDef,
    ListPipelineExecutionsOutputTypeDef,
    ListPipelinesOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListWebhookItemTypeDef,
    ListWebhooksOutputTypeDef,
    OutputArtifactTypeDef,
    PaginatorConfigTypeDef,
    PipelineContextTypeDef,
    PipelineDeclarationTypeDef,
    PipelineExecutionSummaryTypeDef,
    PipelineExecutionTypeDef,
    PipelineMetadataTypeDef,
    PipelineSummaryTypeDef,
    PollForJobsOutputTypeDef,
    PollForThirdPartyJobsOutputTypeDef,
    PutActionRevisionOutputTypeDef,
    PutApprovalResultOutputTypeDef,
    PutWebhookOutputTypeDef,
    ResponseMetadata,
    RetryStageExecutionOutputTypeDef,
    S3ArtifactLocationTypeDef,
    S3LocationTypeDef,
    SourceRevisionTypeDef,
    StageContextTypeDef,
    StageDeclarationTypeDef,
    StageExecutionTypeDef,
    StageStateTypeDef,
    StartPipelineExecutionOutputTypeDef,
    StopExecutionTriggerTypeDef,
    StopPipelineExecutionOutputTypeDef,
    TagTypeDef,
    ThirdPartyJobDataTypeDef,
    ThirdPartyJobDetailsTypeDef,
    ThirdPartyJobTypeDef,
    TransitionStateTypeDef,
    UpdatePipelineOutputTypeDef,
    WebhookAuthConfigurationTypeDef,
    WebhookDefinitionTypeDef,
    WebhookFilterRuleTypeDef,
)

def get_structure() -> AWSSessionCredentialsTypeDef:
    return {
      ...
    }
```
